/*
|-----------------------------------------------------------------------------
| Basic VIEW
|-----------------------------------------------------------------------------
*/
define(function (require) {
	/*Define require deps*/
	var $ = require('af'),
	ui = require('ui'),
	Config = require('config'),
	Backbone = require('backbone'),
	Handlebars = require('handlebars'),
	Util =  require('util'),
	BasicPair  = require('pairs/basicPair'),
	mainMarkup = require('text!templates/category.html');
	require('carousel');



	var theView = Backbone.View.extend({

		template: Handlebars.compile(mainMarkup),
		numberSlides:0,
		dealsToShow:[],

		events:{
			'tap .catHeader .arrowRight' : 'goToNextSubcategory',
			'tap .catHeader .arrowLeft' : 'goToPrevSubcategory',
			'tap .favBtn': 'addTofavs',
			'tap .faceBtn': 'shareFacebook',
			'tap .wrapperCard .close' : 'closeSlide'
		},

		initialize: function(options){
			this.options = options;
			this.render();
		},

		render: function(){
			window.mapView = true; //change global value for the sidebar not to move
			var self = this;
			$.feat.nativeTouchScroll=false;

			_.bindAll(this, 'cleanup');
			self.currentSubcat = 0;
			self.numOfSubcats = 0;
			self.catId = this.options.catId;
			self.elmId = '#category'+this.options.catId;

			/*Aparently the scroll in Android only works when addContentDiv has full html*/
			// $.ui.addContentDiv(self.elmId, '<span class="loadingInPanel">.....</span>');
			// $.ui.loadDiv(self.elmId,false,false,'slide');
			// self.setElement($(self.elmId));
			$.ui.toggleNavMenu('false');
            $.feat.nativeTouchScroll=false;

			if(navigator.geolocation) {
				navigator.geolocation.getCurrentPosition(function(position) {
					self.fetchData(position);
				}, function(error){
                    alert("No hemos recibido tu ubicación, por favor activa tu GPS asegurandote que esté en modo alta precisión y despues presiona Aceptar");
                    window.location.reload();
                }, {timeout: 15000})
			}else{
				self.fetchData();
			}


		},
		addTofavs : function(e){
			e.preventDefault();
			var self = this;
			var dealId = $(e.currentTarget).attr('data-id');
			$(e.currentTarget).addClass("active");
			Util.saveToFavs(self.deals.get(dealId));

		},
		shareFacebook: function(e){
			e.preventDefault();
			var self = this;
			var dealId = $(e.currentTarget).attr('data-id');
			var deal = self.deals.get(dealId);

			Util.shareItem(deal,this.options.catId);
		},
		fetchData:function(position){
			var ratio = "/10";
			if(position!= ""){
				loc = '/'+position.coords.latitude+"/"+position.coords.longitude;
			}else{
				loc = "";
			}
			var self = this;
			$.ajax({
				url: Config.server+'categories/'+this.options.catId+loc+ratio,
				type:'GET',
				success: function(data){
					$.ui.hideMask();
					self.parseData(data);
				},
				error: function(){
					//TODO: error message;
					Util.noConnectionMessage();
				}
			});
		},
		parseData:function(data){
			var self = this;
			var jsonData = JSON.parse(data);
			self.has_subcategories = jsonData.has_subcategories;
			var screenSize = window.innerHeight;
			screenSize = screenSize-160;
			self.screenFit = screenSize;

			if(self.has_subcategories === true){

				self.subcategories = new BasicPair.Collection(jsonData.subcategories);
				self.numOfSubcats = self.subcategories.length;
				self.numberSlides = self.numOfSubcats;
				self.subcategories.screenFit = screenSize

				if(App.favs){
					var dealData = self.subcategories.toJSON();
					for(var catList=0; catList< dealData.length; catList++){
						var currentCatData = dealData[catList];
						for(var item=0; item<App.favs.models.length; item++){
							favId = App.favs.models[item].id;
							for(var dealItem = 0; dealItem<currentCatData.agreements.length; dealItem++){
								if(favId == currentCatData.agreements[dealItem].id){
									currentCatData.agreements[dealItem].fav = "active";
									break;
								}else if(!currentCatData.agreements[dealItem].fav){
									currentCatData.agreements[dealItem].fav = "";
								}
							}
						}
					}
				}
				self.compiledTemplate = self.template({subcategories:self.subcategories.toJSON(), has_subcategories:self.has_subcategories,screenFit:screenSize,idCategory:self.catId});
				self.deals = new BasicPair.Collection();
				for (var i = 0; i < self.subcategories.length; i++) {
					self.deals.add(self.subcategories.toJSON()[i].agreements);
					var agreements = self.subcategories.toJSON()[i].agreements;
					for(var j =0; j < agreements.length;j++){

						self.dealsToShow.push(agreements[j].branches);
					}

				}
			}else{
				self.deals = new BasicPair.Collection(jsonData.agreements);
				self.numOfSubcats = 1;
				self.numberSlides = self.numOfSubcats;

				if(App.favs){

					var dealData = self.deals.toJSON();

					for(var item=0; item<App.favs.models.length; item++){
						favId = App.favs.models[item].id;
						for(var dealItem = 0; dealItem<dealData.length; dealItem++){

							if(favId == dealData[dealItem].id){
								dealData[dealItem].fav = "active";
								break;
							}else if(!dealData[dealItem].fav){
								dealData[dealItem].fav = "";
							}
						}
					}
				}


				self.compiledTemplate = self.template({
						title:jsonData.name,
						deals:dealData,
						screenFit:screenSize,
						idCategory:self.catId,
						has_subcategories:self.has_subcategories});
				var agreements = jsonData.agreements;
                self.dealsToShow = [];
					for(var j =0; j < agreements.length;j++){
                        
						self.dealsToShow.push(agreements[j].branches);
					}
			}

			self.initialSetup();
		},
		setCarousel:function(){
			var self = this;

			for(i=0; i < self.numberSlides;i++){
				$("#categoryCarousel"+self.catId+'l'+i).carousel({
					pagingDiv: +self.catId+"carousel_dots"+i,
					pagingCssName: "dot",
					pagingCssNameSelected: "dot_selected",
					preventDefaults:false,
					vertical:false,
					wrap:false

				});
			}
		},
		initialSetup : function(){
			var self = this;

			$.ui.addContentDiv(self.elmId, self.compiledTemplate);
			$.ui.loadDiv(self.elmId,false,false,'slide');
			self.setElement($(self.elmId));
			$.ui.toggleNavMenu('false');
            

			// $(self.elmId).html(self.compiledTemplate);

			setTimeout(function(){
				self.checkArrows();
				$('#catHold'+self.currentSubcat).css({'display':'block', 'opacity': '1'});
				$('#catTit'+self.currentSubcat).css({'display':'block', 'opacity': '1'});
				self.createScroller('#catHold'+self.currentSubcat);
			},400);
			self.setCarousel();


		},
		closeSlide: function(e){
			e.preventDefault();
			var self = this;
			$('#maincategories').hide();
			Util.putStoresMarkers(self.dealsToShow);
		},
		cleanup: function() {
			this.undelegateEvents();
			$(this.el).empty();
		},
		goToNextSubcategory: function(){

			var self = this;
			if(self.currentSubcat >= self.numOfSubcats-1 ){
				return;
			}
			self.moveCurrentSubcat(self.currentSubcat, 'left');
			self.currentSubcat++;
			self.checkArrows();
			self.moveHiddenSubcat(self.currentSubcat, 'next');
		},
		goToPrevSubcategory: function(){

			var self = this;
			if(self.currentSubcat <= 0 ){
				return;
			}
			self.moveCurrentSubcat(self.currentSubcat, 'right');
			self.currentSubcat--;
			self.checkArrows();
			self.moveHiddenSubcat(self.currentSubcat, 'prev');
		},
		moveCurrentSubcat:function(elemId, to){
			var self = this;
			var windowWidth = $(window).width();
			var xdir;
			var f = to=='left'? xdir =  windowWidth*-1:xdir =  windowWidth;
			$('#catHold'+elemId).css3Animate({
				x: xdir,
				time: "300ms",
				callback: function(){
					self.onAnimationCompleted('#catHold'+elemId);
				}
			});
			$('#catTit'+elemId).css3Animate({
				x: xdir,
				time: "300ms",
				callback: function(){
					self.onAnimationCompleted('#catTit'+elemId);
				}
			});
		},
		moveHiddenSubcat:function(elemId, to){
			var self = this;
			var windowWidth = $(window).width();
			var xdir;
			var f = to=='next'? xdir = windowWidth :xdir =  windowWidth*-1;
			$('#catHold'+elemId).css({
				'display': 'block'
			});
			var tmp = new $.css3AnimateQueue();
			tmp.push({
				id: 'catHold'+elemId,
				x: xdir,
				opacity: 1,
				time: "0ms"
			});
			tmp.push({
				id: 'catHold'+elemId,
				x: 0,
				time: "300ms"
			});
			tmp.push(function () {
				self.createScroller('#catHold'+elemId);
			});
			tmp.run();
			$('#catTit'+elemId).css({
				'display': 'block'
			});
			var tmp2 = new $.css3AnimateQueue();
			tmp2.push({
				id: 'catTit'+elemId,
				x: xdir,
				opacity: 1,
				time: "0ms"
			});
			tmp2.push({
				id: 'catTit'+elemId,
				x: 0,
				time: "300ms"
			});
			tmp2.push(function () {
				self.createScroller('#catTit'+elemId);
			});
			tmp2.run();
		},
		createScroller: function(el){

			//$(el).find('.categorySlider').scroller(); //needed for android only

		},
		checkArrows : function(){
			var self = this;
			if(self.currentSubcat == self.numOfSubcats-1){
				$('.catHeader .r').css('opacity', 0.1);
				$('.catHeader .l').css('opacity', 1);
			}else if(self.currentSubcat === 0){
				$('.catHeader .r').css('opacity', 1);
				$('.catHeader .l').css('opacity', 0.1);
			}else{
				$('.catHeader .r').css('opacity', 1);
				$('.catHeader .l').css('opacity', 1);
			}
		},
		onAnimationCompleted: function(el){
			setTimeout(function(){
				$(el).css('display','none');
			},200);
		},
		destroyView: function(view) {

			// COMPLETELY UNBIND THE VIEW

			view.undelegateEvents();

			//view.el.removeData().unbind();

			// Remove view from DOM
			view.remove();
			Backbone.View.prototype.remove.call(view);

		}

	});


return theView;


});
