/*
|-----------------------------------------------------------------------------
| Basic VIEW
|-----------------------------------------------------------------------------
*/
define(function (require) {
	/*Define require deps*/
  var $ = require('af'),
      ui = require('ui'),
      Backbone = require('backbone'),
      Handlebars = require('handlebars'),
			Config = require('config'),
			Util = require('util'),
      mainMarkup = require('text!templates/home.html'),
      Deals = require('pairs/deal');
      require('carousel');



	var theView = Backbone.View.extend({

		template: Handlebars.compile(mainMarkup),
		carousel:'',
		carouselInteerval:0,
        carouselStocks:'',
		carouselInteervalStocks:0,

		events:{
			'tap .favBtn': 'addTofavs',
			'tap .faceBtn': 'shareFacebook',
			'touchstart #homeCarousel':'removeIterval',
			'touchend #homeCarousel':'setAutoRotate',
            'touchstart #stocks':'removeItervalStocks',
			'touchend #stocks':'setAutoRotateStocks'
		},
		initialize: function(){
            stringJsonServices = "";
			this.render();
		},

		render: function(){
			var self = this;
			self.elmId = '#home';
			self.removeIterval();
            self.removeItervalStocks();
			$.ui.toggleNavMenu('false');
			$('#mainHeader .lower').removeClass('open');
            $('#mainHeader .upper .handle').removeClass("hidden");
			self.fetchData();
		},
        getIndicators:function(){
            var self = this;
            if(document.getElementById("stocks").innerHTML.length == 0){
                $.ajax({
                    url: "http://last.creditocolsubsidio.com/public/api/indicadores",
                    type:'GET',
                    success: function(data){
                        var obj = JSON.parse(data);
                        obj = obj.indicators;
                        var htmlIndicators = "";
                        var pathImg = {sube:"img/indicatorUp.png", baja:"img/indicatorDown.png", igual:""};
                        for(var i=0; i<(Object.keys(obj).length); i++){
                                htmlIndicators = htmlIndicators+'</div><div class="stocks_item"><div class="stockWidthFull">'+obj[i]["display"]+' <strong><span>'+obj[i]["value"]+'</span></strong><img src="'+pathImg[obj[i]["behavior"]]+'"></div>';
                        }
                        document.getElementById("stocks").innerHTML = htmlIndicators;
                        self.setCarouselStocks();
                    }
                });
            }else{
                self.setCarouselStocks();
            }
        },
		fetchData : function(){
			var self = this;
			self.deals = new Deals.Collection();
			self.deals.fetch({
				url: Config.server+'categories/home',
				success:function(){
					$.ui.hideMask();
					$('#whiteMask').addClass('hide');
					self.makeView();
                    self.getIndicators();
				},
				error: function(){
					//TODO: error message;
					Util.noConnectionMessage();
				}
			});
		},
		makeView:function(){
			$.ui.hideMask();
			var self = this;

			if(App.favs){
				var dealData = self.deals.toJSON();
				for(var item=0; item<dealData.length; item++){
					if(App.favs.get(dealData[item].id)){
						dealData[item].fav = "active";
					}else{
						dealData[item].fav = "";
					}
				}
			}

			var html = this.template({deals: dealData});

			$.ui.toggleNavMenu('false');
			//unabled scroll on home slides
			$.feat.nativeTouchScroll=true;

			$.ui.addContentDiv(self.elmId, html);
			//$.ui.loadContent(self.elmId,false,false,'slide');
			$.ui.loadDiv(self.elmId,false,false,'slide');
			this.setElement($(self.elmId));

			$.feat.nativeTouchScroll=false;
			//$(self.elmId).html(html);
			self.setCarousel();
		},
		setCarousel:function(){
			var self = this;
			carousel = $("#homeCarousel").carousel({
				pagingDiv: "carousel_dots",
				pagingCssName: "dot",
				pagingCssNameSelected: "dot_selected",
				preventDefaults:false,
				vertical:false,
				wrap:false

			});

			self.setAutoRotate();
		},
		setAutoRotate:function(){
			var self = this;
			window.carouselInterval = setInterval(self.setAutoCarousel,5000);
		},
		removeIterval:function(){
			var self = this;
			clearInterval(window.carouselInterval);
		},
		setAutoCarousel:function(){
			var self = this;
			if($("#home").length>0){
				var nextStep =0;
				if(carousel.carouselIndex+1 < carousel.childrenCount){
					nextStep = carousel.carouselIndex+1;
				}
				carousel.onMoveIndex(nextStep,1000);
			}else{
				clearInterval(window.carouselInterval);
			}
		},
        setCarouselStocks:function(){
			var self = this;
            carouselStocks = $("#stocks").carousel({
                preventDefaults:false,
                vertical:false,
                wrap:false
            });
            self.setAutoRotateStocks();
		},
		setAutoRotateStocks:function(){
			var self = this;
			window.carouselIntervalStocks = setInterval(self.setAutoCarouselStocks,5000);
		},
		removeItervalStocks:function(){
			var self = this;
			clearInterval(window.carouselIntervalStocks);
		},
		setAutoCarouselStocks:function(){
			var self = this;
			if($("#home").length>0){
				var nextStep =0;
				if(carouselStocks.carouselIndex+1 < carouselStocks.childrenCount){
					nextStep = carouselStocks.carouselIndex+1;
				}
                carouselStocks.onMoveIndex(nextStep,1000);
			}else{
				clearInterval(window.carouselIntervalStocks);
			}
		},
		addTofavs : function(e){
			e.preventDefault();

			$(e.currentTarget).addClass("active");
			var self = this;
			var dealId = $(e.currentTarget).attr('data-id');
			Util.saveToFavs(self.deals.get(dealId));

		},
		shareFacebook: function(e){
			e.preventDefault();
			var self = this;
			var dealId = $(e.currentTarget).attr('data-id');
			var deal = self.deals.get(dealId);
			Util.shareItem(deal,1);
		},
		close:function(e){
			this.undelegateEvents();
			this.removeIterval();
		}

	});


	return theView;


});
