/*
|-----------------------------------------------------------------------------
| Basic VIEW
|-----------------------------------------------------------------------------
*/
define(function (require) {
	/*Define require deps*/
	var $ = require('af'),
	ui = require('ui'),
	Backbone = require('backbone'),
	Handlebars = require('handlebars'),
	Util = require('util'),
	Config = require('config'),
	mainMarkup = require('text!templates/how.html');



	var theView = Backbone.View.extend({

		template: Handlebars.compile(mainMarkup),
		events: {
			// 'tap .cardSmall .delete .btn': 'openConfirmDialog'
			'tap .stepsTitlesBox .r' : 'goToNextStep',
			'tap .stepsTitlesBox .l' : 'goToPrevStep'
		},

		initialize: function(){
			this.render();
		},

		render: function(){
			$.ui.hideMask();
			var self = this;
			_.bindAll(this, 'cleanup');
			self.currentStep = 0;
			self.numOfSteps = 0;

			self.elmId = '#how';
			/*Aparently the scroll in Android only works when addContentDiv has full html*/
			// $.ui.addContentDiv(self.elmId, '<span class="loadingInPanel">.....</span>');
			// $.ui.loadDiv(self.elmId,false,false,'slide');
			// self.setElement($(self.elmId));
			$.ui.toggleNavMenu('false');
			$('#mainHeader .lower').removeClass('open');
			self.fetchData();
		},
		fetchData: function(){
			var self =  this;
			$.ajax({
				url: Config.server+ 'infocards',
				success: function(data){
					self.items = JSON.parse(data);
					self.numOfSteps = self.items.length;
					self.loadView();
				},
				error: function(){
					Util.noConnectionMessage();
				}
			});
		},
		loadView: function(data){
			var self = this;
			$.ui.addContentDiv(self.elmId, self.template({cards:self.items}));
			$.ui.loadDiv(self.elmId,false,false,'slide');
			self.setElement($(self.elmId));
			$.ui.toggleNavMenu('false');
			setTimeout(function(){
				self.checkArrows();
				// $(self.elmId).html(self.template({cards:self.items}));
				$('#tit'+self.currentStep).css({'display':'block', 'opacity': '1'});
				$('#step'+self.currentStep).css({'display':'block', 'opacity': '1'});
				$('#image'+self.currentStep).css({'display':'block', 'opacity': '1'});
			},400);
		},
		goToNextStep:function(){
			var self = this;
			if(self.currentStep >= self.numOfSteps-1 ){
				return;
			}
			self.moveCurrentStep(self.currentStep, 'left');
			self.currentStep++;
			self.checkArrows();
			self.moveHiddenStep(self.currentStep, 'next');
		},
		goToPrevStep:function(){
			var self = this;
			if(self.currentStep <= 0 ){
				return;
			}
			self.moveCurrentStep(self.currentStep, 'right');
			self.currentStep--;
			self.checkArrows();
			self.moveHiddenStep(self.currentStep, 'prev');

		},
		moveCurrentStep:function(elemId, to){
			var self = this;
			var windowWidth = $(window).width();
			var xdir;
			var xdirTit;
			var f = to=='left'? xdir =  windowWidth*-1:xdir =  windowWidth;
			var f2 = to=='left'? xdirTit = -50 :xdirTit = 50;
			$('#step'+elemId).css3Animate({
				x: xdir,
				time: "300ms",
				callback: function(){
					self.onAnimationCompleted('#step'+elemId);
				}
			});
			$('#image'+elemId).css3Animate({
				x: xdir,
				opacity: 0,
				time: "300ms",
				callback: function(){
					self.onAnimationCompleted('#image'+elemId);
				}
			});
			$('#tit'+elemId).css3Animate({
				x: xdirTit,
				opacity: 0,
				time: "300ms",
				callback: function(){
					self.onAnimationCompleted('#tit'+elemId);
				}
			});
		},
		moveHiddenStep:function(elemId, to){
			var self = this;
			var windowWidth = $(window).width();
			var xdir;
			var xdirTit;
			var f = to=='next'? xdir = windowWidth :xdir =  windowWidth*-1;
			var f2 = to=='next'? xdirTit = 50 :xdirTit = -50;

			$('#step'+elemId).css({
				'display': 'block'
			});
			var tmp = new $.css3AnimateQueue();
			tmp.push({
				id: 'step'+elemId,
				x: xdir,
				opacity: 1,
				time: "0ms"
			});
			tmp.push({
				id: 'step'+elemId,
				x: 0,
				time: "300ms"
			});
			tmp.run();

			$('#tit'+elemId).css({
				'display': 'block'
			});
			var tmp2 = new $.css3AnimateQueue();
			tmp2.push({
				id: 'tit'+elemId,
				x: xdirTit,
				time: "0ms"
			});
			tmp2.push({
				id: 'tit'+elemId,
				x: 0,
				opacity: 1,
				time: "300ms"
			});
			tmp2.run();

			$('#image'+elemId).css({
				'display': 'block'
			});
			var tmp3 = new $.css3AnimateQueue();
			tmp3.push({
				id: 'image'+elemId,
				x: xdirTit,
				time: "0ms"
			});
			tmp3.push({
				id: 'image'+elemId,
				x: 0,
				opacity: 1,
				time: "300ms"
			});
			tmp3.run();
		},
		onAnimationCompleted: function(el){
			setTimeout(function(){
				$(el).css('display','none');
			},200);
		},
		checkArrows : function(){
			var self = this;
			if(self.currentStep == self.numOfSteps-1){
				$('.stepsTitlesBox .r').css('opacity', 0.1);
				$('.stepsTitlesBox .l').css('opacity', 1);
			}else if(self.currentStep === 0){
				$('.stepsTitlesBox .r').css('opacity', 1);
				$('.stepsTitlesBox .l').css('opacity', 0.1);
			}else{
				$('.stepsTitlesBox .r').css('opacity', 1);
				$('.stepsTitlesBox .l').css('opacity', 1);
			}
		},
		cleanup: function() {
			this.undelegateEvents();
			$(this.el).empty();
		}

	});


return theView;


});