/*
|-----------------------------------------------------------------------------
| Basic VIEW
|-----------------------------------------------------------------------------
*/
define(function (require) {
	/*Define require deps*/
	var $ = require('af'),
	ui = require('ui'),
	Backbone = require('backbone'),
	Handlebars = require('handlebars'),
	Util = require('util'),
	Config = require('config'),
	BasicPair = require('pairs/basicPair'),
	mainMarkup = require('text!templates/search.html');



	var theView = Backbone.View.extend({

		template: Handlebars.compile(mainMarkup),
		events: {
			// 'tap .cardSmall .delete .btn': 'openConfirmDialog'
		},

		initialize: function(options){
			this.options = options;
			this.render();
		},

		render: function(){
			$.ui.hideMask();
			var self = this;

			var elmId = '#search'+self.options.rand;
			self.elmId = elmId;
			$.ui.addContentDiv(elmId, self.template());
			$(elmId).addClass('searchPanel');
			$.ui.loadDiv(elmId,false,false,'slide');
			self.setElement($(elmId));
			$.ui.toggleNavMenu('false');

			self.fetchDataAgreement();
			self.fetchDataServices();
		},
		fetchDataAgreement : function(){
			//fetch data
			var self = this;
			var val = $('#searchForm .term').val();
			var term = val.toLowerCase();
			$.ajax({
				url: Config.server+'search/agreements',
				data: {query: term},
				type: 'POST',
				success: function(data){
					var temp = Handlebars.compile(self.listMarkupAgreement());
					var html = temp({title: 'ACUERDOS', items:JSON.parse(data)});
					$(self.elmId).find('.agreements').html(html);
				},
				error: function(err){
					console.log(err.response);
					Util.noConnectionMessage();
				}
			});
		},
		fetchDataServices : function(){
			//fetch data
			var self = this;
			var val = $('#searchForm .term').val();
			var term = val.toLowerCase();
			$.ajax({
				url: Config.server+'search/services',
				data: {query: term},
				type: 'POST',
				success: function(data){
					var temp = Handlebars.compile(self.listMarkupServices());
					var html = temp({title: 'SERVICIOS', items:JSON.parse(data)});
					$(self.elmId).find('.services').html(html);
				},
				error: function(){
					Util.noConnectionMessage();
				}
			});
		},

		listMarkupAgreement: function (){
			var title = '<div class="bubleTitle agreementsTitle">'+
										'<span class="bubble">{{items.length}}</span><span class="text">{{title}}</span></div>';
			var list = '<ul class="list agreementsList" >{{#each items}}'+
								'<li><a href="#deal/{{id}}" data-ignore="true">{{name}}</a></li>'+
							'{{/each}}</ul>';
			return title+list;
		},
		listMarkupServices: function (){
			var title = '<div class="bubleTitle agreementsTitle">'+
										'<span class="bubble">{{items.length}}</span><span class="text">{{title}}</span></div>';
			var list = '<ul class="list agreementsList" >{{#each items}}'+
								'<li><a href="#services/{{id}}" data-ignore="true">{{name}}</a></li>'+
							'{{/each}}</ul>';
			return title+list;
		}

	});


return theView;


});
