/*
|-----------------------------------------------------------------------------
| Basic VIEW
|-----------------------------------------------------------------------------
*/
define(function (require) {
	/*Define require deps*/
	var $ = require('af'),
	ui = require('ui'),
	Backbone = require('backbone'),
	Handlebars = require('handlebars'),
	Config = require('config'),
	Util = require('util'),
	BasicPair = require('pairs/basicPair'),
	mainMarkup = require('text!templates/serviceDetail.html');



	var theView = Backbone.View.extend({

		template: Handlebars.compile(mainMarkup),
		events: {
			'tap .closeBtn': 'closeCard',
			'tap .openBtn': 'openCard',
			'tap .favBtn': 'addTofavs',
			'tap .faceBtn': 'shareFacebook'
		},

		allMarkers:[],

		initialize: function(options){
			this.options = options;
			this.render();
		},

		render: function(){

			window.mapView = true; //change global value for the sidebar not to move

			var self = this;
			self.elmId = '#service'+this.options.itemId;
			$.ui.addContentDiv(self.elmId, '<span class="loadingInPanel">.....</span>');
			$.ui.loadDiv(self.elmId,false,false,'slide');
			$(self.elmId).addClass('dealPage');
			self.setElement($(self.elmId));
			$.ui.toggleNavMenu('false');
			self.fetchData();
		},
		addTofavs: function(e){
			e.preventDefault();
			var self = this;
			$(e.currentTarget).addClass("active");
			Util.saveToFavsService(self.service);
		},
		shareFacebook: function(e){
			e.preventDefault();
			var self = this;
			Util.shareService(this.options.itemId, this.options.catId);
		},
		fetchData: function(){
			$.ui.hideMask();
			var self =  this;

			if(App.services.length > 1){
				self.service = new BasicPair.Model(App.services.get(this.options.catId).toJSON());
				$(self.elmId).html(self.template({service:self.service.toJSON()}));

				Util.putStoresMarkers(self.service.toJSON().providers)
				//self.initmap();
			}else{
				$.ajax({
					url: Config.server+'services',
					type:'GET',
					success: function(data){
						$.ui.hideMask();
						var jsonData = JSON.parse(data);
						App.services.reset(jsonData);
						self.service = new BasicPair.Model(App.services.get(self.options.catId).toJSON());
						$(self.elmId).html(self.template({service:self.service.toJSON()}));
						Util.putStoresMarkers(self.service.toJSON().providers)
						//self.initmap();
					},
					error: function(){
						Util.noConnectionMessage();
					}
				});
			}


		},
		closeCard: function(e){
			$('.infoBox').addClass('close');
			$('.openBtn').addClass('open');
		},
		openCard: function(e){
			$('.infoBox').removeClass('close');
			$('.openBtn').removeClass('open');
		},
		initmap: function(){
			var self =this;
			self.infowindow =  new google.maps.InfoWindow({
				content: ''
			});
			self.markerBounds = new google.maps.LatLngBounds();
			var mapOptions = {
          // center: new google.maps.LatLng(-34.397, 150.644),
          zoom: 13,
          mapTypeId: google.maps.MapTypeId.ROADMAP,
          mapTypeControl:false,
					streetViewControl: false
        };
			self.map = new google.maps.Map(document.getElementById("map"), mapOptions);

			self.directionsDisplay = new google.maps.DirectionsRenderer();
			self.directionsService = new google.maps.DirectionsService();
			self.directionsDisplay.setMap(this.map);

			if(navigator.geolocation) {
				navigator.geolocation.getCurrentPosition(function(position) {
				var pos = new google.maps.LatLng(position.coords.latitude,position.coords.longitude);
				self.userPosition = pos;
				marker = new google.maps.Marker({
					map:self.map,
					animation: google.maps.Animation.DROP,
					position: pos
				});
				self.markerBounds.extend(pos);
				self.map.setCenter(pos);
				self.gotGeolocation = true;
				self.putStoresMarkers(pos);
				// self.map.fitBounds(self.markerBounds);
				}, function() {
					alert('No podemos encontrar tu ubicación');
					var pos = new google.maps.LatLng(4.598056,-74.075833);
					self.gotGeolocation = false;
					marker = new google.maps.Marker({
						map:self.map,
						animation: google.maps.Animation.DROP,
						position: pos
					});
					self.markerBounds.extend(pos);
					self.map.setCenter(pos);
					self.putStoresMarkers(pos);
				});
			}
			 self.putStoresMarkers();
		},

		putStoresMarkers:function(pos){
			var self=this;
			var length = self.service.toJSON().providers.length;
			for (var i = 0; i < length; i++) {
				var provider = self.service.toJSON().providers[i];
				self.putStoresMarkersWait(provider, i, length);
			}
		},
		putStoresMarkersWait: function(provider,wait, length){
			var self = this;
			var bluePin = {
				url: 'img/pin.png',
				scaledSize: new google.maps.Size(30, 50)
			};
			var redPin = {
				url: 'img/pinRed.png',
				scaledSize: new google.maps.Size(30, 50)
			};
			setTimeout(function(){
				var lat = provider.lat;
				var lng = provider.lng;
				var pos = new google.maps.LatLng(lat,lng);
				self.markerBounds.extend(pos);
				marker = new google.maps.Marker({
					// map:self.map,
					animation: google.maps.Animation.DROP,
					position: pos,
					id:provider.id
				});
				if(provider.id == self.options.itemId){
					//marker.icon = redPin;
				}
				self.addMarkerListener(marker);
				self.allMarkers.push(marker);
				if(wait == length-1){
					var markerCluster = new MarkerClusterer(self.map, self.allMarkers);
				}
			}, 0*wait);
		},
		addMarkerListener: function(marker){
			var self=this;
			google.maps.event.addListener(marker, 'click', function() {
				if(self.gotGeolocation){
					self.calcRoute(marker.getPosition());
				}

        var markerInfo = _.where(self.service.toJSON().providers, {id:marker.id});
        var str = '<h3>'+markerInfo[0].name+'</h3>'+
								'<p>'+markerInfo[0].address+'</p>'+
								'<p>'+markerInfo[0].telephone+'</p>';
        self.infowindow.setContent(str);
        self.infowindow.open(self.map, this);
			});
		},
		calcRoute: function(to) {
			var self = this;
			var request = {
				origin:self.userPosition,
				destination:to,
				travelMode: google.maps.TravelMode.DRIVING
			};
			self.directionsService.route(request, function(result, status) {
				if (status == google.maps.DirectionsStatus.OK) {
					self.directionsDisplay.setDirections(result);
				}
			});
		}


	});


return theView;


});
